"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.modifyMockedComponents = exports.mockComponents = void 0;
const compiler_1 = require("@teambit/compiler");
const harmony_testing_load_aspect_1 = require("@teambit/harmony.testing.load-aspect");
const workspace_1 = __importDefault(require("@teambit/workspace"));
const install_1 = require("@teambit/install");
const fs_extra_1 = __importDefault(require("fs-extra"));
const p_map_series_1 = __importDefault(require("p-map-series"));
const path_1 = __importDefault(require("path"));
const tracker_1 = __importDefault(require("@teambit/tracker"));
/**
 * create dummy components, add, link and compile them.
 * if `numOfComponents` is more than one, the components will depend on each other. by default, it's one.
 */
function mockComponents(workspacePath, { numOfComponents = 1, additionalStr = '' } = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const compsDirs = yield createComponents(workspacePath, { numOfComponents, additionalStr });
        const harmony = yield (0, harmony_testing_load_aspect_1.loadManyAspects)([workspace_1.default, tracker_1.default, install_1.InstallAspect, compiler_1.CompilerAspect], workspacePath);
        const workspace = harmony.get(workspace_1.default.id);
        const tracker = harmony.get(tracker_1.default.id);
        yield (0, p_map_series_1.default)(compsDirs, (compDir) => __awaiter(this, void 0, void 0, function* () {
            yield tracker.track({ rootDir: compDir });
        }));
        yield workspace.bitMap.write();
        const install = harmony.get(install_1.InstallAspect.id);
        yield install.link({ rewire: true });
        const compiler = harmony.get(compiler_1.CompilerAspect.id);
        yield compiler.compileOnWorkspace();
    });
}
exports.mockComponents = mockComponents;
/**
 * make the mocked components modified by appending the `additionalStr` to the component files
 */
function modifyMockedComponents(workspacePath, additionalStr = ' ', { numOfComponents = 1 } = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        yield createComponents(workspacePath, { numOfComponents, additionalStr });
    });
}
exports.modifyMockedComponents = modifyMockedComponents;
function createComponents(workspacePath, { numOfComponents = 1, additionalStr = '' } = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const getImp = (index) => {
            if (index === numOfComponents)
                return `module.exports = () => 'comp${index}${additionalStr}';`;
            const nextComp = `comp${index + 1}`;
            return `const ${nextComp} = require('../${nextComp}');
module.exports = () => 'comp${index}${additionalStr} and ' + ${nextComp}();`;
        };
        const numOfComponentsArr = Array(numOfComponents).fill(null);
        return (0, p_map_series_1.default)(numOfComponentsArr, (val, key) => __awaiter(this, void 0, void 0, function* () {
            const i = key + 1;
            const compDir = path_1.default.join(workspacePath, `comp${i}`);
            yield fs_extra_1.default.outputFile(path_1.default.join(compDir, `index.js`), getImp(i));
            return compDir;
        }));
    });
}
//# sourceMappingURL=mock-components.js.map